==> mono-2.4.3.tar.bz2: mono-2.4.3/mcs/class/System.Web/System.Web/ParserError.cs <==
// 
// System.Web.ParserError.cs
//
// Authors:
//	Lluis Sanchez Gual (lluis@novell.com)
//
// (C) 2004 Novell, Inc (http://www.novell.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System.Runtime.Serialization;

namespace System.Web {

	[Serializable]
	public sealed class ParserError
	{
		string _errorText;
		string _virtualPath;
		int _line;

		public ParserError ()
		{
		}

		public ParserError (string errorText, string virtualPath, int line)
		{
			_errorText = errorText;
			_virtualPath = virtualPath;
			_line = line;
		}

		public string ErrorText {
			get { return _errorText; }
			set { _errorText = value; }
		}
		
		public string VirtualPath {
			get { return _virtualPath; }
			set { _virtualPath = value; }
		}

		public int Line {
			get { return _line; }
			set { _line = value; }
		}
	}
}

#endif

==> mono-2.10.2.tar.bz2: mono-2.10.2/mcs/class/System.Web/System.Web/ParserError.cs <==
// 
// System.Web.ParserError.cs
//
// Authors:
//	Lluis Sanchez Gual (lluis@novell.com)
//
// (C) 2004-2009 Novell, Inc (http://www.novell.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//


using System.Runtime.Serialization;

namespace System.Web
{
	[Serializable]
	public sealed class ParserError
	{
		string _errorText;
		string _virtualPath;
		int _line;

		public ParserError ()
		{
		}

		public ParserError (string errorText, string virtualPath, int line)
		{
			_errorText = errorText;
			_virtualPath = virtualPath;
			_line = line;
		}

		public string ErrorText {
			get { return _errorText; }
			set { _errorText = value; }
		}
		
		public string VirtualPath {
			get { return _virtualPath; }
			set { _virtualPath = value; }
		}

		public int Line {
			get { return _line; }
			set { _line = value; }
		}
	}
}
